@@ -10,30 +10,19 @@ import wx
 
 
 class WidgetStyleSelectionDialog(wx.Dialog):
-    """\
-    User dialog to select a style during widget creation
-    """
-
+    "User dialog to select a style during widget creation"
     def __init__(self, dlg_title, box_label, choices):
-        """\
-        Initialise the dialog and draw the content
+        """Initialise the dialog and draw the content
 
-        @param dlg_title: Dialog title
-        @type dlg_title:  str | unicode
-
-        @param box_label: Label of the draw around the listed choices
-        @type box_label:  str | unicode
-
-        @param choices: Choices to select one
-        @type choices:  str
-        """
+        dlg_title: Dialog title
+        box_label: Label of the draw around the listed choices
+        choices: Choices to select one (string list)"""
         wx.Dialog.__init__(self, None, -1, dlg_title)
 
         szr = wx.BoxSizer(wx.VERTICAL)
 
-        self.box = wx.RadioBox(
-            self, wx.ID_ANY, box_label, wx.DefaultPosition, wx.DefaultSize,
-            choices.split('|'), 1, style=wx.RA_SPECIFY_COLS)
+        self.box = wx.RadioBox( self, wx.ID_ANY, box_label, wx.DefaultPosition, wx.DefaultSize,choices.split('|'),
+                                1, style=wx.RA_SPECIFY_COLS )
         self.box.SetSelection(0)
         szr.Add(self.box, 5, wx.ALL | wx.EXPAND, 10)
 
@@ -47,9 +36,5 @@ class WidgetStyleSelectionDialog(wx.Dialog):
         self.CenterOnScreen()
 
     def get_selection(self):
-        """\
-        Return the selected choice.
-
-        @rtype: str
-        """
+        "Return the selected choice."
         return self.box.GetStringSelection()
