@@ -11,29 +11,20 @@ import wcodegen
 
 
 class PythonStaticTextGenerator(wcodegen.PythonWidgetCodeWriter):
-    tmpl = '%(name)s = %(klass)s(%(parent)s, %(id)s, ' \
-           '%(label)s%(style)s)\n'
-
-# end of class PythonStaticTextGenerator
+    tmpl = '%(name)s = %(klass)s(%(parent)s, %(id)s, %(label)s%(style)s)\n'
 
 
 class CppStaticTextGenerator(wcodegen.CppWidgetCodeWriter):
-    tmpl = '%(name)s = new %(klass)s(%(parent)s, %(id)s, ' \
-           '%(label)s%(style)s);\n'
-
-# end of class CppStaticTextGenerator
+    tmpl = '%(name)s = new %(klass)s(%(parent)s, %(id)s, %(label)s%(style)s);\n'
 
 
 def xrc_code_generator(obj):
     xrcgen = common.code_writers['XRC']
 
     class XrcCodeGenerator(xrcgen.DefaultXrcObject):
-        def write(self, *args, **kwds):
-            try:
-                del self.properties['attribute']
-            except KeyError:
-                pass
-            xrcgen.DefaultXrcObject.write(self, *args, **kwds)
+        def write(self, out_file, ntabs):
+            properties = {"attribute":None}
+            xrcgen.DefaultXrcObject.write(self, out_file, ntabs, properties)
 
     return XrcCodeGenerator(obj)
 
@@ -42,5 +33,5 @@ def initialize():
     klass = 'wxStaticText'
     common.class_names['EditStaticText'] = klass
     common.register('python', klass, PythonStaticTextGenerator(klass))
-    common.register('C++', klass, CppStaticTextGenerator(klass))
-    common.register('XRC', klass, xrc_code_generator)
+    common.register('C++',    klass, CppStaticTextGenerator(klass))
+    common.register('XRC',    klass, xrc_code_generator)
